## Keys

`Alt`

`Down`

`Left`

`Right`

`Up`

`\`

`Backspace`

`Back Tab`

`|`

`{`

`}`

`[`

`]`

`Break`

`Browser Back`

`Browser Favorites`

`Browser Forward`

`Browser Home`

`Browser Refresh`

`Browser Search`

`Browser Stop`

## Aliases

`Num +`

`Menu`

`Backspace`

`Backspace`

`Back Tab`

`Break`

## Combos

`Win`+`Shift`+`S`

`Cmd`+`Ctrl`+`D`

## On the Fly Special Key

`Ctrl`+`Alt`+`Special`

## Special Key Added to Key Map

`Ctrl`+`Alt`+`Custom Key`

## Override Original

`Opt`+`Shift`+`S`

## Escape Plus

`Ctrl`+`Alt`+`Special with + sign`

++ctrl+alt+delete++

\`Ctrl`+`Alt`+`Del`

\++ctrl+alt+delete++

++ctrl+alt+delete++

++ctrl+alt+delete++

## Bad Key

++ctrl+alt+bad++